/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: Key.java 526062 2007-04-06 05:33:50Z byrne $
 */

package org.apache.xindice.core.data;


/**
 * Key extends Value by providing a hash value for the Key.
 *
 * @version $Revision: 526062 $, $Date: 2007-04-06 01:33:50 -0400 (Fri, 06 Apr 2007) $
 */
public final class Key extends Value {

    private int hash;


    public Key(Value value) {
        super(value);
    }

    public Key(byte[] data) {
        super(data);
    }

    public Key(byte[] data, int pos, int len) {
        super(data, pos, len);
    }

    public Key(String data) {
        super(data);
    }

    public int getHash() {
        // modeled after String.hashCode()
        if (hash == 0) {
            int tempHash = 0;
            for(int i = 0 ; i < len; i++) {
                tempHash = 31 * tempHash + data[pos + i];
            }
            this.hash = Math.abs(tempHash);
        }
        return hash;
    }

    public boolean equals(Value value) {
        if (value instanceof Key) {
            Key key = (Key) value;
            return getHash() == key.getHash() && compareTo(key) == 0;
        }

        return super.equals(value);
    }

    public int hashCode() {
        return getHash();
    }

    public boolean equals(Object obj) {
        if (obj instanceof Value) {
            return equals((Value) obj);
        }

        return super.equals(obj);
    }
}

