/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: GetDocumentMeta.java 511426 2007-02-25 03:25:02Z vgritsenko $
 */

package org.apache.xindice.server.rpc.messages;

import org.apache.xindice.core.Collection;
import org.apache.xindice.core.meta.MetaData;
import org.apache.xindice.server.rpc.RPCDefaultMessage;
import org.apache.xindice.xml.TextWriter;
import org.apache.xindice.xml.dom.DocumentImpl;

import org.w3c.dom.Document;

import java.util.Hashtable;

/**
 * XML-RPC message to fetch the meta data associated with a document
 *
 * @author <a href="mailto:dviner@apache.org">Dave Viner</a>
 * @version $Revision: 511426 $, $Date: 2007-02-24 22:25:02 -0500 (Sat, 24 Feb 2007) $
 */
public class GetDocumentMeta extends RPCDefaultMessage {

    /**
     * Return the MetaData object for the requested document.
     *
     * This method expects the Hashtable to contain the name of the collection
     * in the RPCDefaultMessage.COLLECTION key, and the name of the document
     * in the RPCDefaultMessage.NAME key.
     * It will return an XML representation of the MetaData object associated
     * with this document. The XML will be stored in the
     * RPCDefaultMessage.RESULT key.
     *
     * @param message the parameters passed to the xmlrpc method.
     * @return Hashtable containing the XML for the requested MetaData object.
     */
    public Hashtable execute(Hashtable message) throws Exception {
        Collection col = getCollection((String) message.get(COLLECTION));
        Hashtable result = new Hashtable();
        if (!col.isMetaEnabled()) {
            // meta information is not enabled !
            throw new Exception(MISSING_META_CONFIGURATION);
        }

        if (!message.containsKey(NAME)) {
            throw new Exception(MISSING_NAME_PARAM);
        }
        String docname = (String) message.get(NAME);
        MetaData meta = col.getDocumentMeta(docname);
        Document doc = new DocumentImpl();
        doc.appendChild(meta.streamToXML(doc, true));

        result.put(RESULT, TextWriter.toString(doc));
        return result;
    }
}
