/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: DeploymentTask.java 511426 2007-02-25 03:25:02Z vgritsenko $
 */

package org.apache.xindice.tools;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;
import org.apache.xindice.server.Xindice;

/**
 * Handles basic deployment of Xindice services using ant.
 *
 * @author <a href="mailto:kstaken@xmldatabases.org">Kimbro Staken</a>
 * @version $Revision: 511426 $, $Date: 2007-02-24 22:25:02 -0500 (Sat, 24 Feb 2007) $
 */
public class DeploymentTask extends Task {

    private String collection = "test/ocs";
    private String db = "Database";
    private String home = "";
    private XMLTools admin = null;

    /**
     * Constructor for creating a new DeploymentTask.
     */
    public DeploymentTask() {
        admin = new XMLTools();
    }

    /**
     *  Sets the Name to use for the document or XMLObject. This method always
     *  sets both documentName and Name on the admin object
     *
     * @param  name  The new Name value
     */
    public void setName(String name) {
        admin.setDocumentName(name);
        admin.setName(name);
    }


    /**
     *  Sets the Home attribute of the DeploymentTask object
     *
     * @param  name  The new Home value
     */
    public void setHome(String name) {
        this.home = name;
    }


    /**
     *  Sets the Path attribute of the DeploymentTask object
     *
     * @param  name  The new Path value
     */
    public void setPath(String name) {
        admin.setFilePath(name);
    }


    /**
     *  Sets the Collection attribute of the DeploymentTask object
     *
     * @param  name  The new Collection value
     */
    public void setCollection(String name) {
        this.collection = name;
    }


    /**
     *  Sets the Database attribute of the DeploymentTask object
     *
     * @param  name  The new Database value
     */
    public void setDatabase(String name) {
        this.db = name;
    }


    /**
     *  Sets the Activity attribute of the DeploymentTask object
     *
     * @param  name  The new Activity value
     */
    public void setActivity(String name) {
        admin.setAction(name);
    }

    /**
     *  Sets the Implementation class attribute of the DeploymentTask object
     *
     * @param  name  The new Activity value
     */
    public void setClass(String name) {
        admin.setImplementClass(name);
    }

    /**
     *  Executes the task.
     *
     * @exception  BuildException  Description of Exception
     */
    public void execute() throws BuildException {
        if (this.home.equals("")) {
            throw new BuildException(
                    "You must specify the home attribute for deployment");
        }

        // Set the home directory so the XMLAdmin object can find its configuration.
        System.getProperties().put(Xindice.PROP_XINDICE_HOME, home);

        // Add the parameters that had defaults
        admin.setDatabaseServer(db);
        admin.setCollectionName(collection);

        // Run the task.
        try {
            admin.execute();
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("Error executing deployment task", e);
        }
    }

}

