/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: AddMultipleDocuments.java 511426 2007-02-25 03:25:02Z vgritsenko $
 */

package org.apache.xindice.tools.command;

import org.apache.xindice.tools.XMLTools;

import org.xmldb.api.DatabaseManager;
import org.xmldb.api.base.Collection;

import java.io.File;
import java.io.FileInputStream;
import java.io.FilenameFilter;
import java.util.Hashtable;

/**
 * AddMultipleDocuments.java is designed to let the user add several Documents
 * to an existing Collection at one time.
 *
 * Documents are added with an ID the same as the file name.
 * This command assumes that the collection being added to already exists!
 *
 * @version $Revision: 511426 $, $Date: 2007-02-24 22:25:02 -0500 (Sat, 24 Feb 2007) $
 */
public class AddMultipleDocuments extends Command {

    public boolean execute(Hashtable table) throws Exception {

        Collection col = null;
        try {

            // Verify that user has supplied necessary arguments
            if (table.get(XMLTools.COLLECTION) == null) {
                System.out.println("ERROR : Collection and switch required");
                return false;
            }

            if ("".equals(table.get(XMLTools.FILE_PATH))) {
                System.out.println("ERROR : Directory name and switch required");
                return false;
            }

            final String local = (String) table.get(XMLTools.LOCAL);

            // Get a Collection reference to the collection
            String colstring = normalizeCollectionURI((String) table.get(XMLTools.COLLECTION),
                                                      local);
            col = DatabaseManager.getCollection(colstring);
            if (col == null) {
                System.out.println("ERROR : Collection not found!");
                return false;
            }

            // Create a collection manager instance for the collection
            // CollectionManager colman = (CollectionManager)col.getService("CollectionManager",XMLDBAPIVERSION);

            // Get a File object for the Directory passed in
            File dir = new File((String) table.get(XMLTools.FILE_PATH));
            if (dir.isDirectory()) {

                String[] children = new String[]{};
                final String ext = (String) table.get(XMLTools.EXTENSION);

                // If the user supplied a file extension, filter on it, else use entire contents of the directory
                if (!ext.equals("")) {
                    children = dir.list(new FilenameFilter() {
                        public boolean accept(File none, String name) {
                            return name.endsWith("." + ext);
                        }
                    });
                } else if (ext.equals("")) {
                    children = dir.list();
                }

                System.out.println("Reading files from: " + dir.getCanonicalPath());

                // Use the functionality already provided in AddDocument command to add this document
                final Command cmd = new AddDocument();

                // Command parameters
                Hashtable localtable = new Hashtable();
                localtable.put(XMLTools.COLLECTION, table.get(XMLTools.COLLECTION));
                if (local != null) {
                    localtable.put(XMLTools.LOCAL, local);
                }

                // Loop over documents, adding to db
                for (int i = 0; i < children.length; i++) {

                    File file = new File(dir, children[i]);
                    if (file.isFile()) {
                        try {
                            // Populate hashtable to pass to AddDocument class
                            localtable.put(XMLTools.NAME_OF, file.getName());
                            localtable.put(XMLTools.FILE_PATH, file.getPath());

                            // Execute the class!
                            cmd.execute(localtable);
                        } catch (Exception e) {
                            System.out.println("Error Adding File: " + file.getName());
                            // System.out.println(e);
                            continue;
                        }
                    } else
                        continue;
                } // for loop
            }

        } finally {
            // Release all resources
            if (col != null) {
                col.close();
            }
        }

        return true;
    }
}
