/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: DeleteIndexer.java 511426 2007-02-25 03:25:02Z vgritsenko $
 */

package org.apache.xindice.tools.command;

import org.apache.xindice.client.xmldb.services.CollectionManager;
import org.apache.xindice.tools.XMLTools;

import org.xmldb.api.DatabaseManager;
import org.xmldb.api.base.Collection;

import java.util.Hashtable;

/**
 * DeleteIndexer.java is designed to let the user delete or drop
 * an Indexer from a named Collection or a nested Collection within
 * the Database.
 *
 * @version $Revision: 511426 $, $Date: 2007-02-24 22:25:02 -0500 (Sat, 24 Feb 2007) $
 */
public class DeleteIndexer extends Command {

    public boolean execute(Hashtable table) throws Exception {

        Collection col = null;
        try {
            if (table.get(XMLTools.COLLECTION) != null) {
                // Get a Collection reference to the collection
                String colstring = normalizeCollectionURI((String) table.get(XMLTools.COLLECTION),
                                                          (String) table.get(XMLTools.LOCAL));
                col = DatabaseManager.getCollection(colstring);
                if (col == null) {
                    System.out.println("ERROR : Collection not found!");
                    return false;
                }

                // Create a collection manager instance for the collection
                CollectionManager colman = (CollectionManager) col.getService("CollectionManager", XMLDBAPIVERSION);

                if (table.get(XMLTools.NAME_OF) != null) {
                    colman.dropIndexer((String) table.get(XMLTools.NAME_OF));
                    System.out.println("DELETED: " + (String) table.get(XMLTools.NAME_OF));
                } else {
                    System.out.println("ERROR : Name switch and Indexer name required");
                }
            } else
                System.out.println("ERROR : Collection and switch required");

        } finally {
            if (col != null) {
                col.close();
            }
        }

        return true;
    }

}

