/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: HelpCommand.java 525295 2007-04-03 21:52:05Z vgritsenko $
 */
package org.apache.xindice.tools.command;

import java.util.Hashtable;

import org.apache.xindice.server.Xindice;
import org.apache.xindice.util.StringUtilities;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;
import org.apache.xindice.tools.XMLTools;

/**
 *
 * @author <a href="mailto:byrne@apache.org">Todd Byrne</a>
 * @version $Revision: 525295 $, $Date: 2007-04-03 17:52:05 -0400 (Tue, 03 Apr 2007) $
 */
public class HelpCommand extends Command {

	public boolean execute(Hashtable table) throws Exception {
		NodeList list = (NodeList)table.get(XMLTools.COMMAND_LIST);

		// This method relies on two things to format the output for help
		//    Method isAdmin() - Tells us if this is an admin instance, used to hide certain output
		//    XML file Commands.xml attribute "helpclass" - used to order output

		String helpClass;  // Holds the helpclass for the current <command> node
		String desc;       // Holds the description for the current <command> node
		String cmdswitch;  // Holds the switch for the current <command> node


		// Show the header and switch commands
		System.out.println();
		System.out.println("Xindice Command Tools v" + Xindice.Version);
		System.out.println();
		System.out.println("Format: xindice action [switch] [parameter]");
		System.out.println();
		System.out.println("Switches:");
		System.out.println("    -c           Collection context (must always be specified),");
		System.out.println("                 can be either canonical name of the collection");
		System.out.println("                 or complete xmldb URL");
		System.out.println("    -e           File extension for multiple documents");
		System.out.println("    -f           File path for document retrieval and storage");
		System.out.println("    -n           Name");
		System.out.println("    -p           Index pattern");
		System.out.println("    -q           Query string");
		System.out.println("    -s           Semi-colon delimited list of namespaces for query in ");
		System.out.println("                 the form prefix=namespace-uri");
		System.out.println("    -l           Use a local database rather then going over the network.");
		System.out.println("                 Should be combined with -d to specify the configuration to use.");
		System.out.println("    -d           Path to the database configuration to use for the local ");
		System.out.println("                 database. Only applies if -l is specified.");
		System.out.println("    -t           Specify the data type in collection index");
		System.out.println("    -v           Verbose");
		System.out.println("    --pagesize   Page size for file pages (default: 4096)");
		System.out.println("    --maxkeysize The maximum size for file keys (default: 0=none)");
		System.out.println("    --pagecount  Number of pages in the primary storage (default: 1024)");
		System.out.println("    --filer      Collection filer, can be HashFiler or BTreeFiler (default: BTreeFiler)");
		System.out.println();

		System.out.println("Actions:");

		// Show all elements with helpclass=document
		// Loop over the commands, printing test from description attribute
		for (int i = 0; i < list.getLength(); i++) {
			helpClass = ((Element) list.item(i)).getAttribute("helpclass");

			if (helpClass.equals("document")) {
				desc = ((Element) list.item(i)).getAttribute("description");
				cmdswitch = ((Element) list.item(i)).getAttribute("switch");
				System.out.println("    " + StringUtilities.leftJustify(cmdswitch, 13) + desc);
			}
		}

		// Loop over the commands, printing text from description attribute
		for (int i = 0; i < list.getLength(); i++) {
			helpClass = ((Element) list.item(i)).getAttribute("helpclass");

			if (helpClass.equals("security")) {
				desc = ((Element) list.item(i)).getAttribute("description");
				cmdswitch = ((Element) list.item(i)).getAttribute("switch");
				System.out.println("    " + StringUtilities.leftJustify(cmdswitch, 13) + desc);
			}
		}

		System.out.println();
		System.out.println("Examples:");
		System.out.println("    xindice ad -c /db/test -f /tmp/xmldocument -n myxmldocument");
		System.out.println("    xindice dd -c /db/test -n myxmldocument");
		System.out.println("    xindice rd -c /db/test/ocs -f a:\\file.xml -n file.xml");
		System.out.println("    xindice xpath -c /db/test/ocs -q test");
		System.out.println("    xindice xpath -c /db/test -s a=http://somedomain.com/schema.xsd -q /a:foo");
		System.out.println("    xindice xupdate -c /db/test -f /path/to/xupdate.xml");
		System.out.println("    xindice xupdate -c /db/test -n document-to-update.xml -f /path/to/xupdate.xml");
		System.out.println();
		System.out.println("For more information, please read the Xindice - Tools Reference Guide");
		System.out.println();
		return true;
	}
}
